======================================================
 Zookeeper Transport - ``kombu.transport.zookeeper``
======================================================

.. currentmodule:: kombu.transport.zookeeper

.. automodule:: kombu.transport.zookeeper

    .. contents::
        :local:

    Transport
    ---------

    .. autoclass:: Transport
        :members:
        :undoc-members:

    Channel
    -------

    .. autoclass:: Channel
        :members:
        :undoc-members:

